@@ -112,21 +112,18 @@ class RegressorCollection:
 
     def __post_init__(self):
         regressors = {
-            "GradiantBoostingQuantile": GradientBoostingQuantileRegressor,
-            "GaussianProcess": GaussianProcessRegressor,
-            "RandomForest": RandomForestRegressor,
-            "ExtraTrees": ExtraTreesRegressor,
+            "GradiantBoostingQuantile": GradientBoostingQuantileRegressor(),
+            "GaussianProcess": GaussianProcessRegressor(),
+            "RandomForest": RandomForestRegressor(),
+            "ExtraTrees": ExtraTreesRegressor(),
         }
         self.selectedRegressors = list()
         for regressor in self.__dataclass_fields__:
             kwargs = getattr(self, regressor)
             # enumerate GaussianProcessRegressors if selected with different kernels
             if regressor == "GaussianProcess":
-                if kwargs == "default":
-                    # pass empty args to run post-init
-                    gaussianRegressors = regressors[regressor]()
-                elif kwargs != None:
-                    gaussianRegressors = regressors[regressor](**kwargs)
+                if kwargs != None:
+                    gaussianRegressors = regressors[regressor].set_params(**kwargs)
                 else:
                     continue
                 for kernel in gaussianRegressors.selectedKernels:
@@ -134,7 +131,9 @@ class RegressorCollection:
             elif kwargs == "default":
                 self.selectedRegressors.append(regressors[regressor])
             elif kwargs != None:
-                self.selectedRegressors.append(regressors[regressor](**kwargs))
+                self.selectedRegressors.append(
+                    regressors[regressor].set_params(**kwargs)
+                )
 
 
 @dataclass
